//
//  AdvCamSettingsViewController.m
//  remote
//
//  Created by Vladimir Starikh on 01.12.2022.
//

#import "AdvCamSettingsViewController.h"
#import "AppDelegate.h"
#import "MenuPlaceholder.h"

#import <controllers_api/RemoteCore.h>
#import <controllers_api/HRAdvCamSettings.h>

@interface AdvCamSettingsViewController () <HRAdvCamSettingsProtocol, MenuPlaceholderDelegate>
{
}

@property (weak) IBOutlet UIButton *btnWB;
@property (weak) IBOutlet UIButton *btnWBTemp;

@property (weak) HRAdvCamSettings *advCamSettings;

@property (strong) MenuPlaceholder *dataWB;
@property (strong) MenuPlaceholder *dataColorTemp;

@end

@implementation AdvCamSettingsViewController

- (void)viewDidLoad {
    [super viewDidLoad];

	AppDelegate *app = (AppDelegate *)[UIApplication sharedApplication].delegate;
	RemoteCore *core = app.core;
	_advCamSettings = core.advCamSettings;
	_advCamSettings.delegate = self;

	_dataWB = [[MenuPlaceholder alloc] initWithButton:_btnWB];
	_dataWB.delegate = self;
	_dataWB.menuName = @"White balance";
	_dataWB.itemPlaceholderName = @"White balance";
	_dataColorTemp = [[MenuPlaceholder alloc] initWithButton:_btnWBTemp];
	_dataColorTemp.delegate = self;
	_dataColorTemp.menuName = @"Color temperature";
	_dataColorTemp.itemPlaceholderName = @"Color temperature";
}

- (void)viewWillAppear:(BOOL)animated
{
	[super viewWillAppear:animated];

	[_advCamSettings updateUI];
}

#pragma mark - implement of HRAdvCamSettings protocol

- (void)advCamSetControlStateChanged
{
	HR_ControlState state = [_advCamSettings controlState:HRAdvCamSet_Controls_WhiteBalance];
	_btnWB.enabled = state.enabled;

	state = [_advCamSettings controlState:HRAdvCamSet_Controls_ColorTemp];
	_btnWBTemp.enabled = state.enabled;
}

- (void)advCamSetAddCbItem:(HRAdvCamSet_Controls)type withName:(NSString *)name andId:(unsigned int)itemId
{
	MenuPlaceholder *data = nil;

	switch (type)
	{
		case HRAdvCamSet_Controls_WhiteBalance:
			data = _dataWB;
			break;
		case HRAdvCamSet_Controls_ColorTemp:
			data = _dataColorTemp;
			break;

		default:
			assert(false);
			return;
	}
	[data itemAdded:name withId:itemId];
}

- (void)advCamSetSetCurCbItem:(HRAdvCamSet_Controls)type andId:(unsigned int)itemId
{
	MenuPlaceholder *data = nil;

	switch (type)
	{
		case HRAdvCamSet_Controls_WhiteBalance:
			data = _dataWB;
			break;
		case HRAdvCamSet_Controls_ColorTemp:
			data = _dataColorTemp;
			break;

		default:
			assert(false);
			return;
	}
	[data setCurrentItem:itemId];
}

- (void)advCamSetClearCB:(HRAdvCamSet_Controls)type
{
	MenuPlaceholder *data = nil;

	switch (type)
	{
		case HRAdvCamSet_Controls_WhiteBalance:
			data = _dataWB;
			break;
		case HRAdvCamSet_Controls_ColorTemp:
			data = _dataColorTemp;
			break;

		default:
			assert(false);
			return;
	}
	[data clearMenu];
}

#pragma mark - implement of ManuPlaceHolderDelegate

- (void)menuPlaceholder:(MenuPlaceholder *)mp itemSelected:(unsigned int)itemId
{
	HRAdvCamSet_Controls hrType;

	if (mp == _dataWB)
		hrType = HRAdvCamSet_Controls_WhiteBalance;
	else if (mp == _dataColorTemp)
		hrType = HRAdvCamSet_Controls_ColorTemp;
	else
	{
		assert(false);
		return;
	}
	[_advCamSettings setCamProperty:hrType andId:itemId];
}

@end
