//
//  MainWiew.m
//  remote
//
//  Created by Vladimir Starikh on 21.11.2022.
//

#import "MainViewController.h"
#import "AppDelegate.h"
#import "DeviceListViewController.h"
#import "CameraSettingsViewController.h"
#import "AdvCamSettingsViewController.h"
#import "Preferences/PreferencesViewController.h"

#import <controllers_api/RemoteCore.h>
#import <controllers_api/HRMainWindow.h>
#import <controllers_api/HRLiveView.h>

@interface MainView () <HRMainWindowProtocol, HRLiveViewDelegate>
{
}

@property (weak) IBOutlet UIButton *btnSelectDevice;
@property (weak) IBOutlet UILabel *lblSelectedDevice;
@property (weak) IBOutlet UIButton *btnCameraSettings;
@property (weak) IBOutlet UIButton *btnAdvCamSettings;
@property (weak) IBOutlet UIButton *btnTakePicture;
@property (weak) IBOutlet UIButton *btnLV;
@property (weak) IBOutlet UIButton *btnAF;
@property (weak) IBOutlet UIImageView *imageView;

@property (weak) HRMainWindow *mainWnd;
@property (weak) HRLiveView *lv;

@end

@implementation MainView

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
	self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
	if (self)
	{
		AppDelegate *appDelegate = (AppDelegate *)[UIApplication sharedApplication].delegate;

		RemoteCore *core = appDelegate.core;
		_mainWnd = core.mainWnd;
		_mainWnd.delegate = self;

		_lv = core.liveView;
		_lv.delegate = self;
	}
	return self;
}

- (void)viewDidLoad
{
	[super viewDidLoad];

	[self controlerStateChanged];
}

- (void)viewWillAppear:(BOOL)animated
{
	[super viewWillAppear:animated];

	[_mainWnd updateUI];
}

- (IBAction)takePictureClicked:(id)sender
{
	if (!_mainWnd)
		return;
	[_mainWnd takeShot];
}

- (IBAction)switchLV:(id)sender
{
	if (!_mainWnd)
		return;
	[_mainWnd switchLV];
}

- (IBAction)deviceListsClicked:(id)sender
{
	DeviceListViewController *cnt = [[DeviceListViewController alloc] initWithNibName:nil bundle:nil];
	[self.navigationController pushViewController:cnt animated:YES];
}

- (IBAction)createMock:(id)sender
{
	AppDelegate *appDelegate = (AppDelegate *)[UIApplication sharedApplication].delegate;

	RemoteCore *core = appDelegate.core;
	[core createMockCamera];
}

- (IBAction)cameraSettingsClicked:(id)sender
{
	CameraSettingsViewController *camSet = [[CameraSettingsViewController alloc] initWithNibName:nil bundle:nil];
	[self.navigationController pushViewController:camSet animated:YES];
}

- (IBAction)advancedCameraSettingsClicked:(id)sender
{
	AdvCamSettingsViewController *camSet = [[AdvCamSettingsViewController alloc] initWithNibName:nil bundle:nil];
	[self.navigationController pushViewController:camSet animated:YES];
}

- (IBAction)preferencesClicked:(id)sender
{
	PreferencesViewController *pref = [[PreferencesViewController alloc] initWithNibName:nil bundle:nil];
	[self.navigationController pushViewController:pref animated:YES];
}

- (IBAction)autofocusClicked:(id)sender
{
	CGPoint pos = CGPointMake(0.5f, 0.5f);
	[_lv autofocusToPoint:pos];
}

#pragma mark -
#pragma mark implement HRMainWindowProtocol

- (void)controlerStateChanged
{
	HR_ControlState state = [_mainWnd controlState:MWControlType_TakePicture];
	_btnTakePicture.enabled = state.enabled;

	state = [_mainWnd controlState:MWControlType_SwitchLV];
	_btnLV.enabled = state.enabled;
	[_btnLV setTitle:state.pushed ? @"LV: On" : @"LV: Off" forState:UIControlStateNormal];

	state = [_mainWnd controlState:MWControlType_Autofocus];
	_btnAF.enabled = state.enabled;
}

- (void)changedCurrentCamera:(NSString *)name
{
	_lblSelectedDevice.text = name;
}

#pragma mark -
#pragma mark implement HRLiveViewDelegate

- (void)lvSwitched:(Boolean)on
{
	if (on == NO)
	{
		__block __weak MainView *weakSelf = self;
		dispatch_async(dispatch_get_main_queue(), ^{
			weakSelf.imageView.image = nil;
		});
	}
}

- (void)imageCreated
{
	__block __weak MainView *weakSelf = self;
	dispatch_async(dispatch_get_main_queue(), ^{
		UIImage *img = [weakSelf.lv lvImage];

		weakSelf.imageView.image = img;
	});
}

@end
