//
//  MenuPlaceholder.m
//  remote
//
//  Created by Vladimir Starikh on 06.12.2022.
//

#import "MenuPlaceholder.h"
#import "ItemData.h"

@interface MenuPlaceholder ()
{
	unsigned int _curItem;
}

@property (weak) UIButton *btn;

@property (strong) NSMutableArray<ItemData *> *data;

@end

@implementation MenuPlaceholder

- (instancetype)initWithButton:(UIButton *)btn
{
	if (self = [super init])
	{
		_btn = btn;
		_data = [NSMutableArray new];
		_curItem = -1;
	}
	return self;
}

- (void)itemAdded:(NSString *)name withId:(unsigned int)itemId
{
	ItemData *data = [ItemData new];
	data.name = name;
	data.itemId = itemId;

	[_data addObject:data];
}

- (void)clearMenu
{
	[_data removeAllObjects];
	_curItem = -1;

	[self makeMenu];
}

- (void)setCurrentItem:(unsigned int)itemId
{
	_curItem = itemId;

	[self makeMenu];
}

- (void)makeMenu
{
	__block __weak MenuPlaceholder *weakSelf = self;

	NSMutableArray *arr = [NSMutableArray new];
	if (_data.count)
	{
		for (ItemData *p in _data)
		{
			NSString *name = p.name;
			NSString *identefier = [NSString stringWithFormat:@"%d", p.itemId];
			UIAction *action = [UIAction actionWithTitle:name image:nil identifier:identefier handler:^(__kindof UIAction * _Nonnull action) {
				id<MenuPlaceholderDelegate> delegate = weakSelf.delegate;
				if ([delegate respondsToSelector:@selector(menuPlaceholder:itemSelected:)])
					[delegate menuPlaceholder:weakSelf itemSelected:(unsigned int)action.identifier.longLongValue];
			}];
			if (p.itemId == _curItem)
				action.state = UIMenuElementStateOn;
			[arr addObject:action];
		}
	}
	else
	{
		UIAction *action = [UIAction actionWithTitle:_itemPlaceholderName image:nil identifier:_itemPlaceholderName handler:^(__kindof UIAction * _Nonnull action) {
		}];
		action.attributes = UIMenuElementAttributesDisabled;
		[arr addObject:action];
	}
	UIMenu *mn = [UIMenu menuWithTitle:_menuName children:arr];
	_btn.menu = mn;
}

@end
