//
//  PrefShootingViewController.m
//  remote
//
//  Created by Vladimir Starikh on 09.12.2022.
//

#import "PrefShootingViewController.h"
#import "../AppDelegate.h"
#import "../MenuPlaceholder.h"

#import <controllers_api/controllers_api.h>

@interface PrefShootingViewController () <HRPrefShootingDelegate, MenuPlaceholderDelegate>

@property (weak) IBOutlet UITextField *edHugeStep;
@property (weak) IBOutlet UITextField *edBigStep;
@property (weak) IBOutlet UITextField *edMediumStep;
@property (weak) IBOutlet UIButton *btnUseLVForShooting;
@property (weak) IBOutlet UITextField *edCustomExposure;

@property (weak) HRPrefShooting *prefShooting;

@property (strong) MenuPlaceholder *mpUseLVForShooting;
@end

@implementation PrefShootingViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

	AppDelegate *appDelegate = (AppDelegate *)[UIApplication sharedApplication].delegate;
	RemoteCore *core = appDelegate.core;
	HRPreferences *preferences = core.preferences;
	_prefShooting = preferences.shooting;
	_prefShooting.delegate = self;

	_mpUseLVForShooting = [[MenuPlaceholder alloc] initWithButton:_btnUseLVForShooting];
	_mpUseLVForShooting.menuName = @"Use LiveView for shooting";
	_mpUseLVForShooting.itemPlaceholderName = @"Use LiveView for shooting";
	_mpUseLVForShooting.delegate = self;
}

- (void)viewWillAppear:(BOOL)animated
{
	[super viewWillAppear:animated];

	[_prefShooting updateUI];
}

- (void)viewDidDisappear:(BOOL)animated
{
	[super viewDidDisappear:animated];

	[_prefShooting setNumericValue:HRPrefShooting_Controls_HugeStep antValue:_edHugeStep.text.intValue];
	[_prefShooting setNumericValue:HRPrefShooting_Controls_BigStep antValue:_edBigStep.text.intValue];
	[_prefShooting setNumericValue:HRPrefShooting_Controls_MediumStep antValue:_edMediumStep.text.intValue];
	[_prefShooting setNumericValue:HRPrefShooting_Controls_CustomExposure antValue:_edCustomExposure.text.intValue];

	[_prefShooting accept];
}

#pragma mark - implement of HRPrefShootingDelegate

- (void)prefShootingAddCBItem:(HRPrefShooting_Controls)type withName:(NSString *)name andId:(unsigned int)itemId
{
	if (type == HRPrefShooting_Controls_UseLvForShooting)
		[_mpUseLVForShooting itemAdded:name withId:itemId];
	else
		assert(false);
}

- (void)prefShootingClearCB:(HRPrefShooting_Controls)type
{
	if (type == HRPrefShooting_Controls_UseLvForShooting)
		[_mpUseLVForShooting clearMenu];
	else
		assert(false);
}

- (void)prefShootingSetCurItemInCB:(HRPrefShooting_Controls)type andId:(unsigned int)itemId
{
	if (type == HRPrefShooting_Controls_UseLvForShooting)
		[_mpUseLVForShooting setCurrentItem:itemId];
	else
		assert(false);
}

- (void)prefShootingNumericValueChanged:(HRPrefShooting_Controls)type andValue:(int)value
{
	NSString *text = [NSString stringWithFormat:@"%d", value];
	switch (type)
	{
		case HRPrefShooting_Controls_HugeStep:
			_edHugeStep.text = text;
			break;
		case HRPrefShooting_Controls_BigStep:
			_edBigStep.text = text;
			break;
		case HRPrefShooting_Controls_MediumStep:
			_edMediumStep.text = text;
			break;
		case HRPrefShooting_Controls_CustomExposure:
			_edCustomExposure.text = text;
			break;

		default:
			assert(false);
			break;
	}
}

#pragma mark - implement of MenuPlaceholderDelegate

- (void)menuPlaceholder:(nonnull MenuPlaceholder *)mp itemSelected:(unsigned int)itemId
{
	if (mp == _mpUseLVForShooting)
		[_prefShooting setCurrentItem:HRPrefShooting_Controls_UseLvForShooting andItemId:itemId];
	else
		assert(false);
}

@end
